
# Security Master Attributes
| Attribute Name          | Categorical | History | Required License                          | Attribute Level | Description                                                                                                                                                                                                                                                                 | Available Values                                                                                                    |
|-------------------------|-------------|---------|-------------------------------------------|-----------------|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------|
| Listing ID              | ❌          |         |                                           | Listing         | A unique identifier assigned to a listing                                                                                                                                                                                                                                   |                                                                                                                     |
| Security ID             | ❌          |         |                                           | Security        | A unique identifier assigned to a security                                                                                                                                                                                                                                  |                                                                                                                     |
| Company ID              | ❌          |         |                                           | Company         | A unique identifier associated with the company                                                                                                                                                                                                                             |                                                                                                                     |
| Company Name            | ❌          | ❌     |                                           | Company         |                                                                                                                                                                                                                                                                             |                                                                                                                     |
| Native Name             | ❌          | ❌      |                                           | Company         | Company's name in its native language                                                                                                                                                                                                                                       |                                                                                                                     |
| Ticker                  | ❌          | ✔️      |                                           | Listing         |                                                                                                                                                                                                                                                                             |                                                                                                                     |
| Company Type            | ✔️          | ❌       |                                           | Company         | The type of the company.                                                                                                                                                                                                                                                    | Company, Investment Firm, Fund                                                                                      |
| Security Type           | ✔️          | ❌       |                                           | Security        | The type of the security.                                                                                                                                                                                                                                                   | Common Equity, Preferred Equity, Equity Depositary Receipts, ETF, REITS                                             |
| Active                  | ✔️          | ✔️      |                                           | Listing         | An indicator that denotes the current status of a listing and, if the listing is inactive, specifies the start date and end date when it was active.                                                                                                                        | active, inactive, suspended                                                                                         |
| Country                 | ✔️          | ✔️      |                                           | Company         | Company's denoted country by Prism39                                                                                                                                                                                                                                        | [ISO 3166](https://www.iso.org/obp/ui/#search)                                                                      |
| Headquarter Country     | ✔️          | ❌       |                                           | Company         | Company's headquarter country (ISO 3166 Alpha-2 Code)                                                                                                                                                                                                                       | [ISO 3166](https://www.iso.org/obp/ui/#search)                                                                      |
| Incorporation Country   | ✔️          | ❌       |                                           | Company         | Company's incorporated country (ISO 3166 Alpha-2 Code)                                                                                                                                                                                                                      | [ISO 3166](https://www.iso.org/obp/ui/#search)                                                                      |
| DS2 Contry              | ✔️          | ❌       |                                           | Company         | Company's denoted country by Datastream 2 package                                                                                                                                                                                                                           | [ISO 3166](https://www.iso.org/obp/ui/#search)                                                                      |
| Trade Currency          | ✔️          | ❌       |                                           | Listing         | Currency code - ISO 4217                                                                                                                                                                                                                                                    | [ISO 4217](https://www.iso.org/iso-4217-currency-codes.html)                                                        |
| Report Currency         | ✔️          | ❌       |                                           | Company         | Currency code - ISO 4217                                                                                                                                                                                                                                                    | [ISO 4217](https://www.iso.org/iso-4217-currency-codes.html)                                                        |
| MIC                     | ✔️          | ✔️      |                                           | Listing         | The Market Identifier Code, a unique identifier for a market or exchange.                                                                                                                                                                                                   | [ISO 20022](https://www.iso20022.org/market-identifier-codes)                                                       |
| Operating MIC           | ✔️          | ✔️      |                                           | Listing         | An operating MIC, also called exchange level MIC, identifies the entity operating an exchange, trading platform, regulated or non-regulated market or a trade reporting facility in a specific country; it is the 'parent' MIC to one or several MICs.                      | [ISO 20022](https://www.iso20022.org/market-identifier-codes)                                                       |
| Bloomberg Exchange      | ✔️          | ✔️      |                                           | Listing         | Exchange code used in Bloomberg                                                                                                                                                                                                                                             |                                                                                                                     |
| Bloomberg Ticker        | ❌          | ✔️      |                                           | Listing         | Ticker code used in Bloomberg                                                                                                                                                                                                                                               |                                                                                                                     |
| RDC Primary             | ✔️          | ✔️      |                                           | Listing         | The primary flag made by RDC packages.                                                                                                                                                                                                                                      | primary, primary_security                                                                                           |
| DS2 Primary             | ✔️          | ✔️      |                                           | Listing         | The primary flag used in Datastream packages.                                                                                                                                                                                                                               | primary, primary_security                                                                                           |
| CIQ Primary             | ✔️          | ✔️       | Capital IQ Related license                | Listing         | The primary flag used in Capital IQ packages.                                                                                                                                                                                                                               | primary, primary_listing, primary_security                                                                          |
| CS Primary              | ✔️          | ✔️      | Compustat related license                 | Listing         | The primary flag used in Compustat packages.                                                                                                                                                                                                                                | primary, primary_usa, primary_can, primary_row                                                                      |
| GICS Sector             | ✔️          | ✔️      | GICS History license or LSEG RDC license  | Company         | The Global Industry Classification Standard sector to which the company belongs.                                                                                                                                                                                            | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| GICS Group              | ✔️          | ✔️      | GICS History license or LSEG RDC license  | Company         | The Global Industry Classification Standard industry group to which the company belongs.                                                                                                                                                                                    | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| GICS Industry           | ✔️          | ✔️      | GICS History license or LSEG RDC license  | Company         | The Global Industry Classification Standard industry to which the company belongs.                                                                                                                                                                                          | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| GICS Sub-Industry       | ✔️          | ✔️      | GICS History license or LSEG RDC license                      | Company         | The Global Industry Classification Standard sub-industry to which the company belongs.                                                                                                                                                                                      | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| TRBC Economic Sector    | ✔️          | ✔️      | TRBC or LSEG RDC license                  | Company         | The Refinitiv Business Classification Economic Sector to which the company belongs.                                                                                                                                                                                         | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| TRBC Business Sector    | ✔️          | ✔️      | TRBC or LSEG RDC license                  | Company         | The Refinitiv Business Classification Business Sector to which the company belongs.                                                                                                                                                                                         | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| TRBC Industry Group     | ✔️          | ✔️      | TRBC or LSEG RDC license                  | Company         | The Refinitiv Business Classification Industry Group to which the company belongs.                                                                                                                                                                                          | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| TRBC Industry           | ✔️          | ✔️      | TRBC or LSEG RDC license                  | Company         | The Refinitiv Business Classification Industry to which the company belongs.                                                                                                                                                                                                | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| TRBC Activity           | ✔️          | ✔️      | TRBC or LSEG RDC license                  | Company         | The Refinitiv Business Classification Activity to which the company belongs.                                                                                                                                                                                                | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| FTSE GCS                | ✔️          | ✔️      | LSEG RDC license                          | Company         | FTSE Global Classification System to which the company belongs. Note that this is not equivalend to FTSE Industry Classification Benchmark(ICB)                                                                                                                             | [GICS](https://www.msci.com/our-solutions/indexes/gics)                                                             |
| SIC                     | ✔️          | ❌      |                                           | Company         | Standard Industrial Classification                                                                                                                                                                                                                                          | [SIC](https://www.sec.gov/corpfin/division-of-corporation-finance-standard-industrial-classification-sic-code-list) |
| NAICS                   | ✔️          | ✔️      |                                           | Company         | North American Industry Classification System                                                                                                                                                                                                                               | [NAICS](https://www.census.gov/naics/)                                                                              |
| CUSIP                   | ❌          | ✔️      | Separate CUSIP license                    | Security        | The Committee on Uniform Security Identification Procedures identifier for the security. The 9-character alphanumeric CUSIP code identifies any North American security for the purposes of facilitating clearing and settlement of trades.                                 |                                                                                                                     |
| SEDOL                   | ❌          | ✔️      | Separate SEDOL license                    | Security        | Stock Exchange Daily Official List (United Kingdom and Ireland), identifiers used in the United Kingdom and Ireland for clearing purposes.                                                                                                                                  |                                                                                                                     |
| ISIN                    | ❌          | ✔️      |                                           | Security        | International Securities Identification Number, used worldwide to identify specific securities such as bonds, stocks (common and preferred), futures, warrants, rights, trusts, commercial paper and options.                                                               |                                                                                                                     |
| CINS                    | ❌          | ✔️      | Separate CUSIP license                    | Security        | The CUSIP International Numbering System identifier for the security.                                                                                                                                                                                                       |                                                                                                                     |
| VALOR                   | ❌          | ✔️      |                                           | Security        | Swiss Valoren                                                                                                                                                                                                                                                               |                                                                                                                     |
| WKN                     | ❌          | ✔️      |                                           | Security        | Wertpapierkennnummer                                                                                                                                                                                                                                                        |                                                                                                                     |
| LEI                     | ❌          | ✔️      |                                           | Company         | Legal Entity Identifier, reference code to uniquely identify a legally distinct entity that engages in a financial transaction.                                                                                                                                             |                                                                                                                     |
| CIK                     | ❌          | ✔️      |                                           | Company         | Central Index Key or CIK number is a unique number assigned to an individual, company, filing agent or foreign government by the United States Securities and Exchange Commission. The number is used to identify its filings in several online databases, including EDGAR. |                                                                                                                     |
| FIGI                    | ❌          | ✔️      |                                           | Listing         | Financial Instrument Global Identifier, a 12-character alpha-numerical code that does not contain information characterizing financial instruments, but serves for uniform unique global identification.                                                                    |                                                                                                                     |
| Composite FIGI          | ❌          | ✔️      |                                           | Listing         | Composite level FIGI, Composite FIGI is issued to represent unique securities across related exchanges, mainly within a same country.                                                                                                                                       |                                                                                                                     |
| Share Class FIGI        | ❌          | ✔️      |                                           | Security        | Security level FIGI                                                                                                                                                                                                                                                         |                                                                                                                     |
| QuotePermID             | ❌          | ✔️      |                                           | Listing         | LSEG Listing level open-source permanent identifiers.                                                                                                                                                                                                                       |                                                                                                                     |
| InstrPermID             | ❌          | ✔️      |                                           | Security        | LSEG Securtiy level open-source permanent Identifiers.                                                                                                                                                                                                                      |                                                                                                                     |
| OrgPermID               | ❌          | ✔️      |                                           | Company         | LSEG Company level open-source permanent Identifiers.                                                                                                                                                                                                                       |                                                                                                                     |
| DS2 exchintcode         | ❌          | ✔️      | DataStream 2 license                      | Listing         | LSEG Datastream 2 listing level identifiers. Indicates Datastream 2 Exchange Code                                                                                                                                                                                           |                                                                                                                     |
| DS2 dsinfocode          | ❌          | ✔️      | DataStream 2 license                      | Listing         | LSEG Datastream 2 listing level identifiers.                                                                                                                                                                                                                                |                                                                                                                     |
| DS2 dseccode            | ❌          | ✔️      | DataStream 2 license                      | Security        | LSEG Datastream 2 security level identifiers.                                                                                                                                                                                                                               |                                                                                                                     |
| DS2 dscmpycode          | ❌          | ✔️      | DataStream 2 license                      | Company         | LSEG Datastream 2 company level identifiers.                                                                                                                                                                                                                                |                                                                                                                     |
| RKD issuecode           | ❌          | ✔️      | LSEG Financial license                    | Listing         | LSEG Financial(prev. Reuters Knowledge Direct) listing level identifier.                                                                                                                                                                                                    |                                                                                                                     |
| RKD cmpcode             | ❌          | ✔️      | LSEG Financial license                    | Company         | LSEG Financial(prev. Reuters Knowledge Direct) company level identifier.                                                                                                                                                                                                    |                                                                                                                     |
| IBES Security EstPermID | ❌          | ✔️      | LSEG I/B/E/S license                      | Listing         | LSEG I/B/E/S V2  security level identifier.                                                                                                                                                                                                                                 |                                                                                                                     |
| IBES Company EstPermID  | ❌          | ✔️      | LSEG I/B/E/S license                      | Company         | LSEG I/B/E/S V2 company level identifier.                                                                                                                                                                                                                                   |                                                                                                                     |
| IBES Ticker             | ❌          | ✔️      | LSEG I/B/E/S license                      | Company         | LSEG I/B/E/S V1 security level identifier.                                                                                                                                                                                                                                  |                                                                                                                     |
| RDC quoteid             | ❌          | ✔️      | LSEG RDC license                          | Listing         | LSEG Reference Data Coverage(RDC) listing level identifier.                                                                                                                                                                                                                 |                                                                                                                     |
| RDC instrid             | ❌          | ✔️      | LSEG RDC license                          | Security        | LSEG Reference Data Coverage(RDC) security level identifier.                                                                                                                                                                                                                |                                                                                                                     |
| RDC orgid               | ❌          | ✔️      | LSEG RDC license                          | Company         | LSEG Reference Data Coverage(RDC) company level identifier.                                                                                                                                                                                                                 |                                                                                                                     |
| CS gvkeyiid             | ❌          | ✔️      | Compustat related package or GICS History | Company         | Compustat Company Level Identifier.                                                                                                                                                                                                                                         |                                                                                                                     |
| CS gvkey                | ❌          | ✔️      | Compustat related package or GICS History | Listing         | Compustat Listing Level Identifier.                                                                                                                                                                                                                                         |                                                                                                                     |
| CIQ tradingitemid       | ❌          | ✔️      | Capital IQ related license                | Listing         | CIQ listing level identifier.                                                                                                                                                                                                                                               |                                                                                                                     |
| CIQ securityid          | ❌          | ✔️      | Capital IQ related license                | Security        | CIQ security level identifier.                                                                                                                                                                                                                                              |                                                                                                                     |
| CIQ companyid           | ❌          | ✔️      | Capital IQ related license                | Company         | CIQ company level identifier.                                                                                                                                                                                                                                               |                                                                                                                     |
| FS fsym_listingid       | ❌          | ✔️      | FactSet related license                   | Listing         | Factset listing level identifier.                                                                                                                                                                                                                                           |                                                                                                                     |
| FS fsym_regionalid      | ❌          | ✔️      | FactSet related license                   | Listing         | Factset country security level identifier.                                                                                                                                                                                                                                  |                                                                                                                     |
| FS fsym_securityid      | ❌          | ✔️      | FactSet related license                   | Security        | Factset security level identifier.                                                                                                                                                                                                                                          |                                                                                                                     |
| FS fsym_entityid        | ❌          | ✔️      | FactSet related license                   | Company         | Factset entity level identifier.                                                                                                                                                                                                                                            |                                                                                                                     |
| SNL Institution ID      | ❌          | ✔️      | SNL related license                       | Company         | SNL Financial databases for the institution.                                                                                                                                                                                                                                |                                                                                                                     |
| IHS Securtiyid          | ❌          | ✔️      | IHS Markit related license                | Company         | IHS security level identifier.                                                                                                                                                                                                                                              |                                                                                                                     |
| MarkIt Red Code         | ❌          | ✔️      | IHS Markit credit risk license            | Company         | The identifier assigned by Markit to indicate credit risk.                                                                                                                                                                                                                  |                                                                                                                     |
| RatingsXpress Entity ID | ❌          | ✔️      | S&P RatingsXpress license                 | Company         | S&P's rating database's entity level identifier.                                                                                                                                                                                                                            |                                                                                                                     |
| Fitch Issuer ID         | ❌          | ✔️      | Fitch credit risk data                    | Company         | The Fitch Issuer Identification Number or FIID is a unique proprietary 12-digit tracking number applied to each issuer of debt rated by Fitch Ratings.                                                                                                                      |                                                                                                                     |
| Moody's Issuer Number   | ❌          | ✔️      | Moody's credit risk data                  | Company         | The Moody's Issuer Number or MIN is a unique 10-digit identifier applied to each issuer of debt rated by Moody's Investor Services.                                                                                                                                         |                                                                                                                     |
| Barra ID                | ❌          | ✔️      | MSCI Barra related risk model license     | Listing         | An identifier used in Barra risk models.                                                                                                                                                                                                                                    |                                                                                                                     |
| CMA Entity ID           | ❌          | ❌       |                                           | Company         | The identifier for the entity in the CMA database.                                                                                                                                                                                                                          |                                                                                                                     |
| RIC                     | ❌          | ✔️      | Separate RIC license                      | Listing         | Refinitiv Identification, ticker-like code used by LSEG to identify financial instruments and indices.                                                                                                                                                                      |                                                                                                                     |

</br>